package com.ff.common.service;

import java.util.List;
import com.ff.common.domain.Currency;

/**
 * 币种Service接口
 * 
 * @author shi
 * @date 2025-02-10
 */
public interface ICurrencyService 
{
    /**
     * 查询币种
     * 
     * @param id 币种主键
     * @return 币种
     */
     Currency selectCurrencyById(Long id);

    /**
     * 查询币种列表
     * 
     * @param currency 币种
     * @return 币种集合
     */
     List<Currency> selectCurrencyList(Currency currency);

    /**
     * 新增币种
     * 
     * @param currency 币种
     * @return 结果
     */
     int insertCurrency(Currency currency);

    /**
     * 修改币种
     * 
     * @param currency 币种
     * @return 结果
     */
     int updateCurrency(Currency currency);

    /**
     * 批量删除币种
     * 
     * @param ids 需要删除的币种主键集合
     * @return 结果
     */
     int deleteCurrencyByIds(Long[] ids);

    /**
     * 删除币种信息
     * 
     * @param id 币种主键
     * @return 结果
     */
     int deleteCurrencyById(Long id);
}
